==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/mn-MN/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Гаалийн талбарууд',
    'manage'                    => 'Manage',
    'field'		                => 'Талбар',
    'about_fieldsets_title'		=> 'Fieldsets-ийн тухай',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Энэ талбарын утгыг мэдээллийн санд оруулна уу',
    'encrypt_field_help'      => 'АНХААРУУЛГА: Талбарыг шифрлэх нь үүнийг ойлгомжгүй болгодог.',
    'encrypted'      	        => 'Шифрлэгдсэн',
    'fieldset'      	        => 'Талбар',
    'qty_fields'      	      => 'Кодууд',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Талбарын нэр',
    'field_name'              => 'Талбарын нэр',
    'field_values'            => 'Хээрийн үнэ цэнэ',
    'field_values_help'       => 'Нэг мөрөнд нэг сонголтыг нэм. Эхний шугамаас бусад хоосон шугамыг орхигдуулах болно.',
    'field_element'           => 'Form Element',
    'field_element_short'     => 'Бүрэлдэхүүн',
    'field_format'            => 'Формат',
    'field_custom_format'     => 'Гаалийн формат',
    'field_custom_format_help'     => 'Энэ талбар дээр regex илэрхийлэл ашиглан баталгаажуулалт хийх боломжтой. "regex:"-ээр эхлэх ёстой. Жишээ нь, өөрийн тохируулсан талбарын утга нь бодит IMEI (15 оронтой тоо) агуулж байгааг баталгаажуулахын тулд та <code>regex:/^[0-9]{15}$/</code> ашиглана.',
    'required'   		          => 'Шаардлагатай',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Загвар ашиглана',
    'order'   		            => 'Захиалга',
    'create_fieldset'         => 'Шинэ талбарт',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Шинэ Гаалийн талбар',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Энэ талбарын үнэ цэнийг мэдээллийн санд шифрлэдэг. Зөвхөн админ хэрэглэгч нар нь буцаагдсан утгыг харах боломжтой байна',
    'show_in_email'     => 'Хэрэглэгчид илгээсэн олголтын имэйлд энэ талбарын утгыг оруулах уу? Шифрлэгдсэн талбаруудыг имэйлд оруулах боломжгүй',
    'show_in_email_short'     => 'Include in emails.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',

];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/mn-MN/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Гаалийн талбарууд',
    'manage'                    => 'Manage',
    'field'		                => 'Талбар',
    'about_fieldsets_title'		=> 'Fieldsets-ийн тухай',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Энэ талбарын утгыг мэдээллийн санд оруулна уу',
    'encrypt_field_help'      => 'АНХААРУУЛГА: Талбарыг шифрлэх нь үүнийг ойлгомжгүй болгодог.',
    'encrypted'      	        => 'Шифрлэгдсэн',
    'fieldset'      	        => 'Талбар',
    'qty_fields'      	      => 'Кодууд',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Талбарын нэр',
    'field_name'              => 'Талбарын нэр',
    'field_values'            => 'Хээрийн үнэ цэнэ',
    'field_values_help'       => 'Нэг мөрөнд нэг сонголтыг нэм. Эхний шугамаас бусад хоосон шугамыг орхигдуулах болно.',
    'field_element'           => 'Form Element',
    'field_element_short'     => 'Бүрэлдэхүүн',
    'field_format'            => 'Формат',
    'field_custom_format'     => 'Гаалийн формат',
    'field_custom_format_help'     => 'Энэ талбар дээр regex илэрхийлэл ашиглан баталгаажуулалт хийх боломжтой. "regex:"-ээр эхлэх ёстой. Жишээ нь, өөрийн тохируулсан талбарын утга нь бодит IMEI (15 оронтой тоо) агуулж байгааг баталгаажуулахын тулд та <code>regex:/^[0-9]{15}$/</code> ашиглана.',
    'required'   		          => 'Шаардлагатай',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Загвар ашиглана',
    'order'   		            => 'Захиалга',
    'create_fieldset'         => 'Шинэ талбарт',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Шинэ Гаалийн талбар',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Энэ талбарын үнэ цэнийг мэдээллийн санд шифрлэдэг. Зөвхөн админ хэрэглэгч нар нь буцаагдсан утгыг харах боломжтой байна',
    'show_in_email'     => 'Хэрэглэгчид илгээсэн олголтын имэйлд энэ талбарын утгыг оруулах уу? Шифрлэгдсэн талбаруудыг имэйлд оруулах боломжгүй',
    'show_in_email_short' => 'Include in emails',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];
